@@ -24,7 +24,6 @@ import Adw from 'gi://Adw';
 import Gdk from 'gi://Gdk';
 import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
-import Geocode from 'gi://GeocodeGlib';
 import Gio from 'gi://Gio';
 import Gtk from 'gi://Gtk';
 
@@ -39,6 +38,7 @@ import {RouteQuery} from './routeQuery.js';
 import {Settings} from './settings.js';
 import * as Utils from './utils.js';
 import * as URIS from './uris.js';
+import { Place } from './place.js';
 
 const Format = imports.format;
 
@@ -49,11 +49,14 @@ export class Application extends Adw.Application {
     // used globally
     static application = null;
     static settings = null;
+    /** @type {PlaceStore} */
     static placeStore = null;
+    /** @type {RoutingDelegator} */
     static routingDelegator = null;
     static geoclue = null;
     static osmEdit = null;
     static normalStartup = true;
+    /** @type {RouteQuery} */
     static routeQuery = null;
 
     constructor() {
@@ -65,7 +68,8 @@ export class Application extends Adw.Application {
 
         super({ application_id: pkg.name,
                 flags: Gio.ApplicationFlags.HANDLES_OPEN |
-                       Gio.ApplicationFlags.HANDLES_COMMAND_LINE });
+                       Gio.ApplicationFlags.HANDLES_COMMAND_LINE,
+                resource_base_path: '/org/gnome/Maps' });
 
         this.add_main_option('local',
                              0,
@@ -132,6 +136,7 @@ export class Application extends Adw.Application {
         try {
             Application.placeStore.load();
         } catch (e) {
+            logError(e);
             log('Failed to parse Maps places file, ' +
                 'subsequent writes will overwrite the file!');
         }
@@ -140,8 +145,6 @@ export class Application extends Adw.Application {
     vfunc_startup() {
         super.vfunc_startup();
 
-        Utils.loadStyleSheet(Gio.file_new_for_uri('resource:///org/gnome/Maps/application.css'));
-
         Application.application = this;
         this._initServices();
 
@@ -374,7 +377,7 @@ GObject.registerClass({
                                                    'The selected place',
                                                    GObject.ParamFlags.READABLE |
                                                    GObject.ParamFlags.WRITABLE,
-                                                   Geocode.Place),
+                                                   Place),
         'adaptive-mode': GObject.ParamSpec.boolean('adaptive-mode',
                                                    'Adaptive Move',
                                                    'Whether the main window is in adaptive (narrow) mode',
