@@ -19,6 +19,8 @@
  * Author: Damián Nohales <damiannohales@gmail.com>
  */
 
+import gettext from 'gettext';
+
 import GeocodeGlib from 'gi://GeocodeGlib';
 import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
@@ -40,6 +42,9 @@ import * as Translations from './translations.js';
 import * as Utils from './utils.js';
 import * as Wikipedia from './wikipedia.js';
 
+const _ = gettext.gettext;
+const ngettext = gettext.ngettext;
+
 // maximum dimension of thumbnails to fetch from Wikipedia
 const THUMBNAIL_FETCH_SIZE = 360;
 
@@ -63,6 +68,8 @@ export class PlaceView extends Gtk.Box {
                                                    'thumbnail-separator',
                                                    'label-title',
                                                    'native-name',
+                                                   'source-label',
+                                                   'source-box',
                                                    'address-label',
                                                    'bubble-main-stack',
                                                    'bubble-content-area',
@@ -71,6 +78,8 @@ export class PlaceView extends Gtk.Box {
                                                    'title-box' ]);
         this._title = ui.labelTitle;
         this._nativeName = ui.nativeName;
+        this._sourceLabel = ui.sourceLabel;
+        this._sourceBox = ui.sourceBox;
         this._thumbnail = ui.bubbleThumbnail;
         this._thumbnailSeparator = ui.thumbnailSeparator;
         this._content = ui.bubbleContentArea;
@@ -110,19 +119,20 @@ export class PlaceView extends Gtk.Box {
                                            hexpand: true });
         this.content.attach(this._placeDetails, 0, 0, 1, 1);
 
-        if (this.place.isCurrentLocation) {
+        if (this.place.isCurrentLocation || !this.place.osmType) {
             this._populate(this.place);
         } else {
             let overpass = new Overpass();
+            let placeItem = Application.placeStore.getPlaceItem(this.place);
 
-            if (Application.placeStore.exists(this.place, null)) {
+            if (placeItem !== null) {
 
                 // If the place is stale, update from Overpass.
-                if (Application.placeStore.isStale(this.place)) {
+                if (placeItem.isStale()) {
                     overpass.populatePlace(this.place,
                                            this._onOverpass.bind(this));
                 } else {
-                    this._place = Application.placeStore.get(this.place);
+                    this._place = placeItem.place;
                     this._populate(this.place);
                 }
             } else if (this.place.store) {
@@ -216,6 +226,13 @@ export class PlaceView extends Gtk.Box {
             if (this._nativeName.get_layout().get_unknown_glyphs_count() === 0)
                 this._nativeName.visible = true;
         }
+
+        if (place.source) {
+            this._sourceLabel.label = place.source;
+            this._sourceBox.visible = true;
+        } else {
+            this._sourceBox.visible = false;
+        }
     }
 
     _onOverpass(success) {
@@ -224,10 +241,7 @@ export class PlaceView extends Gtk.Box {
 
         this._populate(this.place);
 
-        if (Application.placeStore.exists(this.place, null))
-            Application.placeStore.updatePlace(this.place);
-        else
-            Application.placeStore.addPlace(this.place, PlaceStore.PlaceType.RECENT);
+        Application.placeStore.addPlace(this.place);
     }
 
     _formatWikiLink(wiki) {
@@ -291,12 +305,66 @@ export class PlaceView extends Gtk.Box {
         }
 
         if (place.email && Utils.isValidEmail(place.email)) {
-            content.push({ label: _("E-mail"),
+            content.push({ label: _("Email"),
                            icon: 'mail-unread-symbolic',
                            info: GLib.markup_escape_text(place.email, -1),
                            linkUrl: `mailto:${place.email}` });
         }
 
+        if (place.floor) {
+            /* If a reference to a named floor (named or symbolic) exists
+             * refer to it directly.
+             */
+
+            /* Translators:
+             * This is a reference to named building floor, using a label
+             * or a code, as "displayed in the elevator"
+             */
+            content.push({ label: _("Floor"),
+                           icon:  'steps-symbolic',
+                           info:  _("Floor %s").format(place.floor) });
+        } else if (place.level) {
+            /* Else if a floor level relative to ground level exists,
+             * display it indicating the relation to ground, or when 0 that
+             * it's ground level
+             */
+            const level = parseInt(place.level);
+
+            if (!isNaN(level)) {
+                let info;
+
+                if (level === 0) {
+                    info = _("At ground level");
+                } else if (level > 0) {
+                    const levelString = level.toLocaleString();
+
+                    /* Translators:
+                     * This is a reference to a number of floors above
+                     * ground level.
+                     * The %s placeholder is the integer relative number of floors
+                     */
+                    info = ngettext("%s floor above ground level",
+                                    "%s floors above ground level", level)
+                                    .format(levelString);
+                } else {
+                    const levelString = (-level).toLocaleString();
+
+                    /* Translators:
+                     * This is a reference to a number of floors below
+                     * ground level.
+                     * The %s placeholder is the integer relative number of floors
+                     */
+                    info = ngettext("%s floor below ground level",
+                                    "%s floors below ground level", -level)
+                                    .format(levelString);
+                }
+
+                content.push({ label: _("Floor"),
+                               icon:  'steps-symbolic',
+                               info:  info });
+            }
+        }
+
         if (place.isEatingAndDrinking) {
             switch (place.takeaway) {
                 case 'yes':
@@ -586,7 +654,20 @@ export class PlaceView extends Gtk.Box {
         let content = this._createContent(place);
         this._attachContent(content);
 
-        if (place.wikidata && Wikipedia.isValidWikidata(place.wikidata)) {
+        if (place.description) {
+            const box = this._addBox();
+            const descriptionLabel = new Gtk.Label({
+                max_width_chars: 30,
+                wrap: true,
+                xalign: 0,
+                hexpand: true,
+                halign: Gtk.Align.FILL,
+                label: place.description
+            });
+            box.marginTop = 12;
+            box.marginBottom = 18;
+            box.append(descriptionLabel);
+        } else if (place.wikidata && Wikipedia.isValidWikidata(place.wikidata)) {
             let defaultArticle =
                 place.wiki && Wikipedia.isValidWikipedia(place.wiki) ?
                 place.wiki : null;
